import { reactive, ref } from 'vue'
import request from '@/utils/request'
import { showDanger } from '@/utils'

export default () => {
  const loading = ref(false)
  const list = ref([])
  const page = reactive({})
  const detail = reactive({})
  const roomRole = reactive({})
  const roomAuthBox = reactive({})
  const roomKeyBox = reactive({})

  const getList = (data) => {
    loading.value = true
    request({
      loadingId: 'room.list',
      url: '/room/list',
      data: {
        pageNo: 1,
        pageSize: 10,
        ...data,
      },
    })
      .then((res) => {
        const { pageNo, pageSize, endRow, result } = res || {}
        Object.assign(page, {
          pageNo,
          pageSize,
          endRow,
        })
        list.value = pageNo <= 1 ? result : list.value.concat(list.value)
        loading.value = false
      })
      .catch((e) => {
        console.error(e)
        loading.value = false
      })
  }

  // 房源详情--基础信息
  const getDetail = (id) => {
    request({
      loadingId: 'room.view',
      url: '/room/detail',
      params: { id },
    })
      .then((res) => {
        Object.assign(detail, res)
      })
      .catch((e) => {
        console.error(e)
        showDanger('获取详情失败')
      })
  }

  // 角色人信息
  const getRole = (data) => {
    request({
      loadingId: 'room.role',
      url: '/room/role',
      params: {
        roomId: data,
      },
    })
      .then((res) => {
        Object.assign(roomRole, res)
      })
      .catch((e) => {
        console.error(e)
        showDanger('获取角色人失败')
      })
  }

  // 委托书信息
  const getAuth = (data) => {
    request({
      loadingId: 'room.auth',
      url: '/room/auth',
      params: {
        roomId: data,
      },
    })
      .then((res) => {
        Object.assign(roomAuthBox, res)
      })
      .catch((e) => {
        console.error(e)
        showDanger('获取委托书失败')
      })
  }

  // 钥匙信息
  const getKey = (data) => {
    request({
      loadingId: 'room.key',
      url: '/room/key',
      params: {
        roomId: data,
      },
    })
      .then((res) => {
        Object.assign(roomKeyBox, res)
      })
      .catch((e) => {
        console.error(e)
        showDanger('获取钥匙失败')
      })
  }

  // 房源保护
  const updateProtection = (data) => {
    return request({
      url: '/room/protection/update-status',
      data,
      toast: '请稍候...',
    }).then(() => {
      detail.roomInfo.protectionFlag = data.protectionFlag
      return
    })
  }

  // 业主电话
  const addOwnerTel = (params) => {
    return request({
      url: '/room/own-tel/add',
      params,
      toast: '请稍候...',
    }).then(() => {
      const ownerTel = detail.roomInfo.ownerTel || ''
      detail.roomInfo.ownerTel = ownerTel
        .split(',')
        .filter(Boolean)
        .concat(params.newOwnerTel)
        .join(',')
      return
    })
  }

  // 获取楼栋详情
  const getBuilding = (estateId) => {
    return request({
      url: '/room/building',
      params: { estateId },
    })
  }

  // 房源下架
  const closeHouse = (data) => {
    return request({
      url: '/room/close',
      params: { estateId: data.estateId },
      data,
      toast: '请稍候...',
    }).then(() => {
      return
    })
  }

  // 房源编辑
  const houseEdit = (data) => {
    return request({
      url: '/room/save',
      data,
      toast: '请稍候...',
    })
  }

  // 实勘列表
  const getRescList = (roomId) => {
    return request({
      url: '/room/resc/list',
      params: { roomId },
      loadingId: 'room.resc.list',
    })
  }

  // 设置封面
  const setRescCover = (rescId) => {
    return request({
      url: '/room/resc/cover',
      params: { id: rescId },
      toast: '请稍候...',
    })
  }

  // 保存
  const saveResc = (data, roomId) => {
    return request({
      url: '/room/resc/save',
      headers: {
        'Content-Type': 'application/json',
      },
      params: { roomId },
      data,
      toast: '请稍候...',
    })
  }

  // 删除
  const deleteResc = ({ roomId, rescId, rescType }) => {
    return request({
      url: '/room/resc/delete',
      params: { roomId, rescId, rescType },
      toast: '请稍候...',
    })
  }

  // 查看业务房源数
  const countOwnerTel = (ownerTel) => {
    return request({
      url: '/room/owner-tel/count',
      params: { ownerTel },
      toast: '请稍候...',
    })
  }

  // 新增房源
  const addHouse = (params, data) => {
    return request({
      url: '/room/add',
      params,
      data,
      toast: '请稍候...',
    })
  }

  return {
    list,
    page,
    getList,
    detail,
    getDetail,
    loading,
    getRole,
    roomRole,
    roomAuthBox,
    getAuth,
    getKey,
    roomKeyBox,
    updateProtection,
    addOwnerTel,
    getBuilding,
    closeHouse,
    houseEdit,
    getRescList,
    setRescCover,
    saveResc,
    deleteResc,
    countOwnerTel,
    addHouse,
  }
}
